NsfwScanProgress class

Constructors

NsfwScanProgress({required String scanId, required int processed, required int total, required double percent, required String status, String? imagePath, String? error, String? mediaType})
const
NsfwScanProgress.fromMap(Map<String, dynamic> map)
factory

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
imagePath String?
final
isCompleted bool
no setter
mediaType String?
final
percent double
final
processed int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanId String
final
status String
final
total int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited