NsfwBottomActionBar class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NsfwBottomActionBar
Constructors
- NsfwBottomActionBar({Key? key, required bool showWizardControls, required VoidCallback? onBack, required VoidCallback? onForward, required VoidCallback? onRestart, VoidCallback? onCancel, bool backEnabled = true, bool forwardEnabled = true, bool restartEnabled = true, bool showCancel = false, String backLabel = 'Zuruck', String forwardLabel = 'Weiter', String restartLabel = 'Von vorne starten', String cancelLabel = 'Abbrechen', EdgeInsets padding = const EdgeInsets.fromLTRB(12, 8, 12, 12), Color? backgroundColor, Color? shadowColor})
-
const
Properties
- backEnabled → bool
-
final
- backgroundColor → Color?
-
final
- backLabel → String
-
final
- cancelLabel → String
-
final
- forwardEnabled → bool
-
final
- forwardLabel → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onBack → VoidCallback?
-
final
- onCancel → VoidCallback?
-
final
- onForward → VoidCallback?
-
final
- onRestart → VoidCallback?
-
final
- padding → EdgeInsets
-
final
- restartEnabled → bool
-
final
- restartLabel → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → Color?
-
final
- showCancel → bool
-
final
- showWizardControls → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited